# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import stock_pb2 as v1_dot_stock_dot_stock__pb2


class StockServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProductCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductCreateResponse.FromString,
        )
        self.ProductRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductReadResponse.FromString,
        )
        self.ProductUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductUpdateResponse.FromString,
        )
        self.ProductDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/ProductDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.ProductDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.ProductDeleteResponse.FromString,
        )
        self.UomCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomCreateResponse.FromString,
        )
        self.UomRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomReadResponse.FromString,
        )
        self.UomUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomUpdateResponse.FromString,
        )
        self.UomDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/UomDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.UomDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.UomDeleteResponse.FromString,
        )
        self.QuantCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantCreateResponse.FromString,
        )
        self.QuantRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantReadResponse.FromString,
        )
        self.QuantUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantUpdateResponse.FromString,
        )
        self.QuantDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/QuantDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.QuantDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.QuantDeleteResponse.FromString,
        )
        self.LocationCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationCreateResponse.FromString,
        )
        self.LocationRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationReadResponse.FromString,
        )
        self.LocationUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationUpdateResponse.FromString,
        )
        self.LocationDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/LocationDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.LocationDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.LocationDeleteResponse.FromString,
        )
        self.WarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateResponse.FromString,
        )
        self.WarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseReadResponse.FromString,
        )
        self.WarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateResponse.FromString,
        )
        self.WarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteResponse.FromString,
        )
        self.PickingTypeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateResponse.FromString,
        )
        self.PickingTypeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadResponse.FromString,
        )
        self.PickingTypeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateResponse.FromString,
        )
        self.PickingTypeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteResponse.FromString,
        )
        self.RouteCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteCreateResponse.FromString,
        )
        self.RouteRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteReadResponse.FromString,
        )
        self.RouteUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteUpdateResponse.FromString,
        )
        self.RouteDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RouteDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.RouteDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RouteDeleteResponse.FromString,
        )
        self.RuleCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleCreate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleCreateResponse.FromString,
        )
        self.RuleRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleRead",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleReadResponse.FromString,
        )
        self.RuleUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleUpdate",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleUpdateResponse.FromString,
        )
        self.RuleDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.StockService/RuleDelete",
            request_serializer=v1_dot_stock_dot_stock__pb2.RuleDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__pb2.RuleDeleteResponse.FromString,
        )


class StockServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ProductCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RuleDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ProductCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductCreateResponse.SerializeToString,
        ),
        "ProductRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductReadResponse.SerializeToString,
        ),
        "ProductUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductUpdateResponse.SerializeToString,
        ),
        "ProductDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProductDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.ProductDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.ProductDeleteResponse.SerializeToString,
        ),
        "UomCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UomCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomCreateResponse.SerializeToString,
        ),
        "UomRead": grpc.unary_unary_rpc_method_handler(
            servicer.UomRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomReadResponse.SerializeToString,
        ),
        "UomUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UomUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomUpdateResponse.SerializeToString,
        ),
        "UomDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UomDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.UomDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.UomDeleteResponse.SerializeToString,
        ),
        "QuantCreate": grpc.unary_unary_rpc_method_handler(
            servicer.QuantCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantCreateResponse.SerializeToString,
        ),
        "QuantRead": grpc.unary_unary_rpc_method_handler(
            servicer.QuantRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantReadResponse.SerializeToString,
        ),
        "QuantUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.QuantUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantUpdateResponse.SerializeToString,
        ),
        "QuantDelete": grpc.unary_unary_rpc_method_handler(
            servicer.QuantDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.QuantDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.QuantDeleteResponse.SerializeToString,
        ),
        "LocationCreate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationCreateResponse.SerializeToString,
        ),
        "LocationRead": grpc.unary_unary_rpc_method_handler(
            servicer.LocationRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationReadResponse.SerializeToString,
        ),
        "LocationUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationUpdateResponse.SerializeToString,
        ),
        "LocationDelete": grpc.unary_unary_rpc_method_handler(
            servicer.LocationDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.LocationDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.LocationDeleteResponse.SerializeToString,
        ),
        "WarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseCreateResponse.SerializeToString,
        ),
        "WarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseReadResponse.SerializeToString,
        ),
        "WarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseUpdateResponse.SerializeToString,
        ),
        "WarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.WarehouseDeleteResponse.SerializeToString,
        ),
        "PickingTypeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeCreateResponse.SerializeToString,
        ),
        "PickingTypeRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeReadResponse.SerializeToString,
        ),
        "PickingTypeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeUpdateResponse.SerializeToString,
        ),
        "PickingTypeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.PickingTypeDeleteResponse.SerializeToString,
        ),
        "RouteCreate": grpc.unary_unary_rpc_method_handler(
            servicer.RouteCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteCreateResponse.SerializeToString,
        ),
        "RouteRead": grpc.unary_unary_rpc_method_handler(
            servicer.RouteRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteReadResponse.SerializeToString,
        ),
        "RouteUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.RouteUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteUpdateResponse.SerializeToString,
        ),
        "RouteDelete": grpc.unary_unary_rpc_method_handler(
            servicer.RouteDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RouteDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RouteDeleteResponse.SerializeToString,
        ),
        "RuleCreate": grpc.unary_unary_rpc_method_handler(
            servicer.RuleCreate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleCreateResponse.SerializeToString,
        ),
        "RuleRead": grpc.unary_unary_rpc_method_handler(
            servicer.RuleRead,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleReadResponse.SerializeToString,
        ),
        "RuleUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.RuleUpdate,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleUpdateResponse.SerializeToString,
        ),
        "RuleDelete": grpc.unary_unary_rpc_method_handler(
            servicer.RuleDelete,
            request_deserializer=v1_dot_stock_dot_stock__pb2.RuleDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__pb2.RuleDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.StockService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ProductCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductCreate",
            v1_dot_stock_dot_stock__pb2.ProductCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductRead",
            v1_dot_stock_dot_stock__pb2.ProductReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductUpdate",
            v1_dot_stock_dot_stock__pb2.ProductUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/ProductDelete",
            v1_dot_stock_dot_stock__pb2.ProductDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.ProductDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomCreate",
            v1_dot_stock_dot_stock__pb2.UomCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomRead",
            v1_dot_stock_dot_stock__pb2.UomReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomUpdate",
            v1_dot_stock_dot_stock__pb2.UomUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/UomDelete",
            v1_dot_stock_dot_stock__pb2.UomDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.UomDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantCreate",
            v1_dot_stock_dot_stock__pb2.QuantCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantRead",
            v1_dot_stock_dot_stock__pb2.QuantReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantUpdate",
            v1_dot_stock_dot_stock__pb2.QuantUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/QuantDelete",
            v1_dot_stock_dot_stock__pb2.QuantDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.QuantDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationCreate",
            v1_dot_stock_dot_stock__pb2.LocationCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationRead",
            v1_dot_stock_dot_stock__pb2.LocationReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationUpdate",
            v1_dot_stock_dot_stock__pb2.LocationUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/LocationDelete",
            v1_dot_stock_dot_stock__pb2.LocationDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.LocationDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseCreate",
            v1_dot_stock_dot_stock__pb2.WarehouseCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseRead",
            v1_dot_stock_dot_stock__pb2.WarehouseReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseUpdate",
            v1_dot_stock_dot_stock__pb2.WarehouseUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/WarehouseDelete",
            v1_dot_stock_dot_stock__pb2.WarehouseDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.WarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeCreate",
            v1_dot_stock_dot_stock__pb2.PickingTypeCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeRead",
            v1_dot_stock_dot_stock__pb2.PickingTypeReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeUpdate",
            v1_dot_stock_dot_stock__pb2.PickingTypeUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/PickingTypeDelete",
            v1_dot_stock_dot_stock__pb2.PickingTypeDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.PickingTypeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteCreate",
            v1_dot_stock_dot_stock__pb2.RouteCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteRead",
            v1_dot_stock_dot_stock__pb2.RouteReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteUpdate",
            v1_dot_stock_dot_stock__pb2.RouteUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RouteDelete",
            v1_dot_stock_dot_stock__pb2.RouteDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RouteDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleCreate",
            v1_dot_stock_dot_stock__pb2.RuleCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleRead",
            v1_dot_stock_dot_stock__pb2.RuleReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleUpdate",
            v1_dot_stock_dot_stock__pb2.RuleUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RuleDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.StockService/RuleDelete",
            v1_dot_stock_dot_stock__pb2.RuleDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__pb2.RuleDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/stock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/stock.proto\x12\x19pro.omni.oms.api.v1.stock\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc1\x01\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x16\n\x0eproduct_doc_id\x18\x02 \x01(\t\x12\x17\n\x0ftemplate_doc_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xae\x01\n\x03Uom\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nuom_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf5\x01\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\x05\x12\x13\n\x0blocation_id\x18\x03 \x01(\x05\x12\x0c\n\x04lote\x18\x04 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12\x10\n\x08quantity\x18\x06 \x01(\x02\x12\x0e\n\x06uom_id\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf0\x01\n\x08Location\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tparent_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x15\n\rtype_location\x18\x05 \x01(\t\x12\x0f\n\x07\x62\x61rcode\x18\x06 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x02\n\tWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x12\n\ncountry_id\x18\x04 \x01(\x05\x12\x37\n\x16territory_matrix_value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x61\x64\x64ress\x18\x06 \x01(\t\x12\x12\n\ncomplement\x18\x07 \x01(\t\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf1\x03\n\x0bPickingType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rsequence_code\x18\x03 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x04 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x06 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\t \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\n \x01(\x05\x12\x0e\n\x06prefix\x18\x0b \x01(\t\x12\x0f\n\x07padding\x18\x0c \x01(\x05\x12\x18\n\x10number_increment\x18\r \x01(\x05\x12\x1a\n\x12number_next_actual\x18\x0e \x01(\x05\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x10 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9e\x03\n\x05Route\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb6\x02\n\x04Rule\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x04 \x01(\x05\x12\x17\n\x0flocation_src_id\x18\x05 \x01(\x05\x12\x13\n\x0blocation_id\x18\x06 \x01(\x05\x12\x16\n\x0eprocure_method\x18\x07 \x01(\t\x12\x10\n\x08route_id\x18\x08 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\t \x01(\x05\x12\x10\n\x08sequence\x18\n \x01(\x05\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb9\x01\n\x14ProductCreateRequest\x12\x16\n\x0eproduct_doc_id\x18\x01 \x01(\t\x12\x17\n\x0ftemplate_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x15ProductCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x07product\x18\x02 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.Product"\xf0\x02\n\x12ProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x13ProductReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x34\n\x08products\x18\x03 \x03(\x0b\x32".pro.omni.oms.api.v1.stock.Product"\x83\x01\n\x14ProductUpdateRequest\x12\x33\n\x07product\x18\x01 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.Product\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x15ProductUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x07product\x18\x02 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.Product"Z\n\x14ProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15ProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa6\x01\n\x10UomCreateRequest\x12\x12\n\nuom_doc_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x01\n\x11UomCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12+\n\x03uom\x18\x02 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom"\xec\x02\n\x0eUomReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x0fUomReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12,\n\x04uoms\x18\x03 \x03(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom"w\n\x10UomUpdateRequest\x12+\n\x03uom\x18\x01 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x01\n\x11UomUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12+\n\x03uom\x18\x02 \x01(\x0b\x32\x1e.pro.omni.oms.api.v1.stock.Uom"V\n\x10UomDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11UomDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc1\x01\n\x12QuantCreateRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\x05\x12\x13\n\x0blocation_id\x18\x02 \x01(\x05\x12\x0c\n\x04lote\x18\x03 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x10\n\x08quantity\x18\x05 \x01(\x02\x12\x0e\n\x06uom_id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13QuantCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05quant\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcb\x01\n\x11QuantReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x30\n\x06quants\x18\x03 \x03(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant"}\n\x12QuantUpdateRequest\x12/\n\x05quant\x18\x01 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13QuantUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05quant\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Quant"X\n\x12QuantDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe8\x01\n\x15LocationCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x15\n\rtype_location\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61rcode\x18\x05 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x06 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9a\x01\n\x16LocationCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x08location\x18\x02 \x01(\x0b\x32#.pro.omni.oms.api.v1.stock.Location"\xf1\x02\n\x13LocationReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd4\x01\n\x14LocationReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\tlocations\x18\x03 \x03(\x0b\x32#.pro.omni.oms.api.v1.stock.Location"\x86\x01\n\x15LocationUpdateRequest\x12\x35\n\x08location\x18\x01 \x01(\x0b\x32#.pro.omni.oms.api.v1.stock.Location\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9a\x01\n\x16LocationUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x08location\x18\x02 \x01(\x0b\x32#.pro.omni.oms.api.v1.stock.Location"[\n\x15LocationDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16LocationDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8a\x02\n\x16WarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x12\n\ncountry_id\x18\x03 \x01(\x05\x12\x37\n\x16territory_matrix_value\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x12\n\ncomplement\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n\x17WarehouseCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x37\n\twarehouse\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse"\xf2\x02\n\x14WarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n\x15WarehouseReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x38\n\nwarehouses\x18\x03 \x03(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse"\x89\x01\n\x16WarehouseUpdateRequest\x12\x37\n\twarehouse\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n\x17WarehouseUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x37\n\twarehouse\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.Warehouse"\\\n\x16WarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17WarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xbd\x03\n\x18PickingTypeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rsequence_code\x18\x02 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x05 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\x08 \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\t \x01(\x05\x12\x0e\n\x06prefix\x18\n \x01(\t\x12\x0f\n\x07padding\x18\x0b \x01(\x05\x12\x18\n\x10number_increment\x18\x0c \x01(\x05\x12\x1a\n\x12number_next_actual\x18\r \x01(\x05\x12\x36\n\x07\x63ontext\x18\x0e \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x19PickingTypeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12<\n\x0cpicking_type\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType"\xf4\x02\n\x16PickingTypeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xde\x01\n\x17PickingTypeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12=\n\rpicking_types\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType"\x90\x01\n\x18PickingTypeUpdateRequest\x12<\n\x0cpicking_type\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x19PickingTypeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12<\n\x0cpicking_type\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.PickingType"^\n\x18PickingTypeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"f\n\x19PickingTypeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xea\x02\n\x12RouteCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x07 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13RouteCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05route\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Route"\xee\x02\n\x10RouteReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcb\x01\n\x11RouteReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x30\n\x06routes\x18\x03 \x03(\x0b\x32 .pro.omni.oms.api.v1.stock.Route"}\n\x12RouteUpdateRequest\x12/\n\x05route\x18\x01 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Route\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x01\n\x13RouteUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x05route\x18\x02 \x01(\x0b\x32 .pro.omni.oms.api.v1.stock.Route"X\n\x12RouteDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13RouteDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x82\x02\n\x11RuleCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x03 \x01(\x05\x12\x17\n\x0flocation_src_id\x18\x04 \x01(\x05\x12\x13\n\x0blocation_id\x18\x05 \x01(\x05\x12\x16\n\x0eprocure_method\x18\x06 \x01(\t\x12\x10\n\x08route_id\x18\x07 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12\x10\n\x08sequence\x18\t \x01(\x05\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8e\x01\n\x12RuleCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12-\n\x04rule\x18\x02 \x01(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule"\xed\x02\n\x0fRuleReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc8\x01\n\x10RuleReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12.\n\x05rules\x18\x03 \x03(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule"z\n\x11RuleUpdateRequest\x12-\n\x04rule\x18\x01 \x01(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8e\x01\n\x12RuleUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12-\n\x04rule\x18\x02 \x01(\x0b\x32\x1f.pro.omni.oms.api.v1.stock.Rule"W\n\x11RuleDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12RuleDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf1\x1c\n\x0cStockService\x12t\n\rProductCreate\x12/.pro.omni.oms.api.v1.stock.ProductCreateRequest\x1a\x30.pro.omni.oms.api.v1.stock.ProductCreateResponse"\x00\x12n\n\x0bProductRead\x12-.pro.omni.oms.api.v1.stock.ProductReadRequest\x1a..pro.omni.oms.api.v1.stock.ProductReadResponse"\x00\x12t\n\rProductUpdate\x12/.pro.omni.oms.api.v1.stock.ProductUpdateRequest\x1a\x30.pro.omni.oms.api.v1.stock.ProductUpdateResponse"\x00\x12t\n\rProductDelete\x12/.pro.omni.oms.api.v1.stock.ProductDeleteRequest\x1a\x30.pro.omni.oms.api.v1.stock.ProductDeleteResponse"\x00\x12h\n\tUomCreate\x12+.pro.omni.oms.api.v1.stock.UomCreateRequest\x1a,.pro.omni.oms.api.v1.stock.UomCreateResponse"\x00\x12\x62\n\x07UomRead\x12).pro.omni.oms.api.v1.stock.UomReadRequest\x1a*.pro.omni.oms.api.v1.stock.UomReadResponse"\x00\x12h\n\tUomUpdate\x12+.pro.omni.oms.api.v1.stock.UomUpdateRequest\x1a,.pro.omni.oms.api.v1.stock.UomUpdateResponse"\x00\x12h\n\tUomDelete\x12+.pro.omni.oms.api.v1.stock.UomDeleteRequest\x1a,.pro.omni.oms.api.v1.stock.UomDeleteResponse"\x00\x12n\n\x0bQuantCreate\x12-.pro.omni.oms.api.v1.stock.QuantCreateRequest\x1a..pro.omni.oms.api.v1.stock.QuantCreateResponse"\x00\x12h\n\tQuantRead\x12+.pro.omni.oms.api.v1.stock.QuantReadRequest\x1a,.pro.omni.oms.api.v1.stock.QuantReadResponse"\x00\x12n\n\x0bQuantUpdate\x12-.pro.omni.oms.api.v1.stock.QuantUpdateRequest\x1a..pro.omni.oms.api.v1.stock.QuantUpdateResponse"\x00\x12n\n\x0bQuantDelete\x12-.pro.omni.oms.api.v1.stock.QuantDeleteRequest\x1a..pro.omni.oms.api.v1.stock.QuantDeleteResponse"\x00\x12w\n\x0eLocationCreate\x12\x30.pro.omni.oms.api.v1.stock.LocationCreateRequest\x1a\x31.pro.omni.oms.api.v1.stock.LocationCreateResponse"\x00\x12q\n\x0cLocationRead\x12..pro.omni.oms.api.v1.stock.LocationReadRequest\x1a/.pro.omni.oms.api.v1.stock.LocationReadResponse"\x00\x12w\n\x0eLocationUpdate\x12\x30.pro.omni.oms.api.v1.stock.LocationUpdateRequest\x1a\x31.pro.omni.oms.api.v1.stock.LocationUpdateResponse"\x00\x12w\n\x0eLocationDelete\x12\x30.pro.omni.oms.api.v1.stock.LocationDeleteRequest\x1a\x31.pro.omni.oms.api.v1.stock.LocationDeleteResponse"\x00\x12z\n\x0fWarehouseCreate\x12\x31.pro.omni.oms.api.v1.stock.WarehouseCreateRequest\x1a\x32.pro.omni.oms.api.v1.stock.WarehouseCreateResponse"\x00\x12t\n\rWarehouseRead\x12/.pro.omni.oms.api.v1.stock.WarehouseReadRequest\x1a\x30.pro.omni.oms.api.v1.stock.WarehouseReadResponse"\x00\x12z\n\x0fWarehouseUpdate\x12\x31.pro.omni.oms.api.v1.stock.WarehouseUpdateRequest\x1a\x32.pro.omni.oms.api.v1.stock.WarehouseUpdateResponse"\x00\x12z\n\x0fWarehouseDelete\x12\x31.pro.omni.oms.api.v1.stock.WarehouseDeleteRequest\x1a\x32.pro.omni.oms.api.v1.stock.WarehouseDeleteResponse"\x00\x12\x80\x01\n\x11PickingTypeCreate\x12\x33.pro.omni.oms.api.v1.stock.PickingTypeCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.PickingTypeCreateResponse"\x00\x12z\n\x0fPickingTypeRead\x12\x31.pro.omni.oms.api.v1.stock.PickingTypeReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.PickingTypeReadResponse"\x00\x12\x80\x01\n\x11PickingTypeUpdate\x12\x33.pro.omni.oms.api.v1.stock.PickingTypeUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.PickingTypeUpdateResponse"\x00\x12\x80\x01\n\x11PickingTypeDelete\x12\x33.pro.omni.oms.api.v1.stock.PickingTypeDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.PickingTypeDeleteResponse"\x00\x12n\n\x0bRouteCreate\x12-.pro.omni.oms.api.v1.stock.RouteCreateRequest\x1a..pro.omni.oms.api.v1.stock.RouteCreateResponse"\x00\x12h\n\tRouteRead\x12+.pro.omni.oms.api.v1.stock.RouteReadRequest\x1a,.pro.omni.oms.api.v1.stock.RouteReadResponse"\x00\x12n\n\x0bRouteUpdate\x12-.pro.omni.oms.api.v1.stock.RouteUpdateRequest\x1a..pro.omni.oms.api.v1.stock.RouteUpdateResponse"\x00\x12n\n\x0bRouteDelete\x12-.pro.omni.oms.api.v1.stock.RouteDeleteRequest\x1a..pro.omni.oms.api.v1.stock.RouteDeleteResponse"\x00\x12k\n\nRuleCreate\x12,.pro.omni.oms.api.v1.stock.RuleCreateRequest\x1a-.pro.omni.oms.api.v1.stock.RuleCreateResponse"\x00\x12\x65\n\x08RuleRead\x12*.pro.omni.oms.api.v1.stock.RuleReadRequest\x1a+.pro.omni.oms.api.v1.stock.RuleReadResponse"\x00\x12k\n\nRuleUpdate\x12,.pro.omni.oms.api.v1.stock.RuleUpdateRequest\x1a-.pro.omni.oms.api.v1.stock.RuleUpdateResponse"\x00\x12k\n\nRuleDelete\x12,.pro.omni.oms.api.v1.stock.RuleDeleteRequest\x1a-.pro.omni.oms.api.v1.stock.RuleDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.stock_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _PRODUCT._serialized_start = 133
    _PRODUCT._serialized_end = 326
    _UOM._serialized_start = 329
    _UOM._serialized_end = 503
    _QUANT._serialized_start = 506
    _QUANT._serialized_end = 751
    _LOCATION._serialized_start = 754
    _LOCATION._serialized_end = 994
    _WAREHOUSE._serialized_start = 997
    _WAREHOUSE._serialized_end = 1271
    _PICKINGTYPE._serialized_start = 1274
    _PICKINGTYPE._serialized_end = 1771
    _ROUTE._serialized_start = 1774
    _ROUTE._serialized_end = 2188
    _RULE._serialized_start = 2191
    _RULE._serialized_end = 2501
    _PRODUCTCREATEREQUEST._serialized_start = 2504
    _PRODUCTCREATEREQUEST._serialized_end = 2689
    _PRODUCTCREATERESPONSE._serialized_start = 2692
    _PRODUCTCREATERESPONSE._serialized_end = 2843
    _PRODUCTREADREQUEST._serialized_start = 2846
    _PRODUCTREADREQUEST._serialized_end = 3214
    _PRODUCTREADRESPONSE._serialized_start = 3217
    _PRODUCTREADRESPONSE._serialized_end = 3426
    _PRODUCTUPDATEREQUEST._serialized_start = 3429
    _PRODUCTUPDATEREQUEST._serialized_end = 3560
    _PRODUCTUPDATERESPONSE._serialized_start = 3563
    _PRODUCTUPDATERESPONSE._serialized_end = 3714
    _PRODUCTDELETEREQUEST._serialized_start = 3716
    _PRODUCTDELETEREQUEST._serialized_end = 3806
    _PRODUCTDELETERESPONSE._serialized_start = 3808
    _PRODUCTDELETERESPONSE._serialized_end = 3906
    _UOMCREATEREQUEST._serialized_start = 3909
    _UOMCREATEREQUEST._serialized_end = 4075
    _UOMCREATERESPONSE._serialized_start = 4078
    _UOMCREATERESPONSE._serialized_end = 4217
    _UOMREADREQUEST._serialized_start = 4220
    _UOMREADREQUEST._serialized_end = 4584
    _UOMREADRESPONSE._serialized_start = 4587
    _UOMREADRESPONSE._serialized_end = 4784
    _UOMUPDATEREQUEST._serialized_start = 4786
    _UOMUPDATEREQUEST._serialized_end = 4905
    _UOMUPDATERESPONSE._serialized_start = 4908
    _UOMUPDATERESPONSE._serialized_end = 5047
    _UOMDELETEREQUEST._serialized_start = 5049
    _UOMDELETEREQUEST._serialized_end = 5135
    _UOMDELETERESPONSE._serialized_start = 5137
    _UOMDELETERESPONSE._serialized_end = 5231
    _QUANTCREATEREQUEST._serialized_start = 5234
    _QUANTCREATEREQUEST._serialized_end = 5427
    _QUANTCREATERESPONSE._serialized_start = 5430
    _QUANTCREATERESPONSE._serialized_end = 5575
    _QUANTREADREQUEST._serialized_start = 5578
    _QUANTREADREQUEST._serialized_end = 5944
    _QUANTREADRESPONSE._serialized_start = 5947
    _QUANTREADRESPONSE._serialized_end = 6150
    _QUANTUPDATEREQUEST._serialized_start = 6152
    _QUANTUPDATEREQUEST._serialized_end = 6277
    _QUANTUPDATERESPONSE._serialized_start = 6280
    _QUANTUPDATERESPONSE._serialized_end = 6425
    _QUANTDELETEREQUEST._serialized_start = 6427
    _QUANTDELETEREQUEST._serialized_end = 6515
    _QUANTDELETERESPONSE._serialized_start = 6517
    _QUANTDELETERESPONSE._serialized_end = 6613
    _LOCATIONCREATEREQUEST._serialized_start = 6616
    _LOCATIONCREATEREQUEST._serialized_end = 6848
    _LOCATIONCREATERESPONSE._serialized_start = 6851
    _LOCATIONCREATERESPONSE._serialized_end = 7005
    _LOCATIONREADREQUEST._serialized_start = 7008
    _LOCATIONREADREQUEST._serialized_end = 7377
    _LOCATIONREADRESPONSE._serialized_start = 7380
    _LOCATIONREADRESPONSE._serialized_end = 7592
    _LOCATIONUPDATEREQUEST._serialized_start = 7595
    _LOCATIONUPDATEREQUEST._serialized_end = 7729
    _LOCATIONUPDATERESPONSE._serialized_start = 7732
    _LOCATIONUPDATERESPONSE._serialized_end = 7886
    _LOCATIONDELETEREQUEST._serialized_start = 7888
    _LOCATIONDELETEREQUEST._serialized_end = 7979
    _LOCATIONDELETERESPONSE._serialized_start = 7981
    _LOCATIONDELETERESPONSE._serialized_end = 8080
    _WAREHOUSECREATEREQUEST._serialized_start = 8083
    _WAREHOUSECREATEREQUEST._serialized_end = 8349
    _WAREHOUSECREATERESPONSE._serialized_start = 8352
    _WAREHOUSECREATERESPONSE._serialized_end = 8509
    _WAREHOUSEREADREQUEST._serialized_start = 8512
    _WAREHOUSEREADREQUEST._serialized_end = 8882
    _WAREHOUSEREADRESPONSE._serialized_start = 8885
    _WAREHOUSEREADRESPONSE._serialized_end = 9100
    _WAREHOUSEUPDATEREQUEST._serialized_start = 9103
    _WAREHOUSEUPDATEREQUEST._serialized_end = 9240
    _WAREHOUSEUPDATERESPONSE._serialized_start = 9243
    _WAREHOUSEUPDATERESPONSE._serialized_end = 9400
    _WAREHOUSEDELETEREQUEST._serialized_start = 9402
    _WAREHOUSEDELETEREQUEST._serialized_end = 9494
    _WAREHOUSEDELETERESPONSE._serialized_start = 9496
    _WAREHOUSEDELETERESPONSE._serialized_end = 9596
    _PICKINGTYPECREATEREQUEST._serialized_start = 9599
    _PICKINGTYPECREATEREQUEST._serialized_end = 10044
    _PICKINGTYPECREATERESPONSE._serialized_start = 10047
    _PICKINGTYPECREATERESPONSE._serialized_end = 10211
    _PICKINGTYPEREADREQUEST._serialized_start = 10214
    _PICKINGTYPEREADREQUEST._serialized_end = 10586
    _PICKINGTYPEREADRESPONSE._serialized_start = 10589
    _PICKINGTYPEREADRESPONSE._serialized_end = 10811
    _PICKINGTYPEUPDATEREQUEST._serialized_start = 10814
    _PICKINGTYPEUPDATEREQUEST._serialized_end = 10958
    _PICKINGTYPEUPDATERESPONSE._serialized_start = 10961
    _PICKINGTYPEUPDATERESPONSE._serialized_end = 11125
    _PICKINGTYPEDELETEREQUEST._serialized_start = 11127
    _PICKINGTYPEDELETEREQUEST._serialized_end = 11221
    _PICKINGTYPEDELETERESPONSE._serialized_start = 11223
    _PICKINGTYPEDELETERESPONSE._serialized_end = 11325
    _ROUTECREATEREQUEST._serialized_start = 11328
    _ROUTECREATEREQUEST._serialized_end = 11690
    _ROUTECREATERESPONSE._serialized_start = 11693
    _ROUTECREATERESPONSE._serialized_end = 11838
    _ROUTEREADREQUEST._serialized_start = 11841
    _ROUTEREADREQUEST._serialized_end = 12207
    _ROUTEREADRESPONSE._serialized_start = 12210
    _ROUTEREADRESPONSE._serialized_end = 12413
    _ROUTEUPDATEREQUEST._serialized_start = 12415
    _ROUTEUPDATEREQUEST._serialized_end = 12540
    _ROUTEUPDATERESPONSE._serialized_start = 12543
    _ROUTEUPDATERESPONSE._serialized_end = 12688
    _ROUTEDELETEREQUEST._serialized_start = 12690
    _ROUTEDELETEREQUEST._serialized_end = 12778
    _ROUTEDELETERESPONSE._serialized_start = 12780
    _ROUTEDELETERESPONSE._serialized_end = 12876
    _RULECREATEREQUEST._serialized_start = 12879
    _RULECREATEREQUEST._serialized_end = 13137
    _RULECREATERESPONSE._serialized_start = 13140
    _RULECREATERESPONSE._serialized_end = 13282
    _RULEREADREQUEST._serialized_start = 13285
    _RULEREADREQUEST._serialized_end = 13650
    _RULEREADRESPONSE._serialized_start = 13653
    _RULEREADRESPONSE._serialized_end = 13853
    _RULEUPDATEREQUEST._serialized_start = 13855
    _RULEUPDATEREQUEST._serialized_end = 13977
    _RULEUPDATERESPONSE._serialized_start = 13980
    _RULEUPDATERESPONSE._serialized_end = 14122
    _RULEDELETEREQUEST._serialized_start = 14124
    _RULEDELETEREQUEST._serialized_end = 14211
    _RULEDELETERESPONSE._serialized_start = 14213
    _RULEDELETERESPONSE._serialized_end = 14308
    _STOCKSERVICE._serialized_start = 14311
    _STOCKSERVICE._serialized_end = 18008
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/users/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13v1/users/user.proto\x12\x1epro.omni.oms.api.v1.users.user\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc2\x03\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sub\x18\x03 \x01(\t\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x10\n\x08username\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x36\n\x08language\x18\x07 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x08timezone\x18\x08 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12*\n\x06groups\x18\t \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x30\n\x0cis_superuser\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\x03mfa\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc8\x01\n\x05Group\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12*\n\x06\x61\x63\x63\x65ss\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd7\x01\n\x06\x41\x63tion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cmicroservice\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf8\x01\n\x06\x41\x63\x63\x65ss\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\x11\n\taction_id\x18\x05 \x01(\t\x12\x36\n\x06\x61\x63tion\x18\x06 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x8f\x03\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x15\n\remail_confirm\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12\x18\n\x10password_confirm\x18\x06 \x01(\t\x12.\n\ngroups_ids\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x30\n\x0cis_superuser\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x08language\x18\t \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x08timezone\x18\n \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"\xed\x02\n\x0fUserReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x10UserReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x33\n\x05users\x18\x03 \x03(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"\x7f\n\x11UserUpdateRequest\x12\x32\n\x04user\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"W\n\x11UserDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12UserDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x19UserChangePasswordRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x18\n\x10password_confirm\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aUserChangePasswordResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x82\x01\n\x16UserChangeEmailRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\remail_confirm\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17UserChangeEmailResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x98\x01\n\x12GroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12.\n\naccess_ids\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x13GroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x34\n\x05group\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"\xee\x02\n\x10GroupReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd0\x01\n\x11GroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x35\n\x06groups\x18\x03 \x03(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"\x82\x01\n\x12GroupUpdateRequest\x12\x34\n\x05group\x18\x01 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x13GroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x34\n\x05group\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"X\n\x12GroupDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13GroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa3\x01\n\x13\x41\x63tionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cmicroservice\x18\x04 \x01(\t\x12\r\n\x05model\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63tionCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"\xef\x02\n\x11\x41\x63tionReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd3\x01\n\x12\x41\x63tionReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x37\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"\x85\x01\n\x13\x41\x63tionUpdateRequest\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63tionUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"Y\n\x13\x41\x63tionDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x41\x63tionDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8c\x01\n\x13\x41\x63\x63\x65ssCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x11\n\taction_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63\x63\x65ssCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"\xef\x02\n\x11\x41\x63\x63\x65ssReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd4\x01\n\x12\x41\x63\x63\x65ssReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x38\n\x08\x61\x63\x63\x65sses\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"\x85\x01\n\x13\x41\x63\x63\x65ssUpdateRequest\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63\x63\x65ssUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"Y\n\x13\x41\x63\x63\x65ssDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x41\x63\x63\x65ssDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"t\n\x14HasPermissionRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xae\x01\n\x15HasPermissionResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x16\n\x0ehas_permission\x18\x02 \x01(\x08\x12\x32\n\x04user\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User2\xb9\x12\n\x0cUsersService\x12u\n\nUserCreate\x12\x31.pro.omni.oms.api.v1.users.user.UserCreateRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserCreateResponse"\x00\x12o\n\x08UserRead\x12/.pro.omni.oms.api.v1.users.user.UserReadRequest\x1a\x30.pro.omni.oms.api.v1.users.user.UserReadResponse"\x00\x12u\n\nUserUpdate\x12\x31.pro.omni.oms.api.v1.users.user.UserUpdateRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserUpdateResponse"\x00\x12u\n\nUserDelete\x12\x31.pro.omni.oms.api.v1.users.user.UserDeleteRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserDeleteResponse"\x00\x12\x8d\x01\n\x12UserChangePassword\x12\x39.pro.omni.oms.api.v1.users.user.UserChangePasswordRequest\x1a:.pro.omni.oms.api.v1.users.user.UserChangePasswordResponse"\x00\x12\x84\x01\n\x0fUserChangeEmail\x12\x36.pro.omni.oms.api.v1.users.user.UserChangeEmailRequest\x1a\x37.pro.omni.oms.api.v1.users.user.UserChangeEmailResponse"\x00\x12x\n\x0bGroupCreate\x12\x32.pro.omni.oms.api.v1.users.user.GroupCreateRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupCreateResponse"\x00\x12r\n\tGroupRead\x12\x30.pro.omni.oms.api.v1.users.user.GroupReadRequest\x1a\x31.pro.omni.oms.api.v1.users.user.GroupReadResponse"\x00\x12x\n\x0bGroupUpdate\x12\x32.pro.omni.oms.api.v1.users.user.GroupUpdateRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupUpdateResponse"\x00\x12x\n\x0bGroupDelete\x12\x32.pro.omni.oms.api.v1.users.user.GroupDeleteRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupDeleteResponse"\x00\x12{\n\x0c\x41\x63tionCreate\x12\x33.pro.omni.oms.api.v1.users.user.ActionCreateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionCreateResponse"\x00\x12u\n\nActionRead\x12\x31.pro.omni.oms.api.v1.users.user.ActionReadRequest\x1a\x32.pro.omni.oms.api.v1.users.user.ActionReadResponse"\x00\x12{\n\x0c\x41\x63tionUpdate\x12\x33.pro.omni.oms.api.v1.users.user.ActionUpdateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionUpdateResponse"\x00\x12{\n\x0c\x41\x63tionDelete\x12\x33.pro.omni.oms.api.v1.users.user.ActionDeleteRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionDeleteResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssCreate\x12\x33.pro.omni.oms.api.v1.users.user.AccessCreateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessCreateResponse"\x00\x12u\n\nAccessRead\x12\x31.pro.omni.oms.api.v1.users.user.AccessReadRequest\x1a\x32.pro.omni.oms.api.v1.users.user.AccessReadResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssUpdate\x12\x33.pro.omni.oms.api.v1.users.user.AccessUpdateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessUpdateResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssDelete\x12\x33.pro.omni.oms.api.v1.users.user.AccessDeleteRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessDeleteResponse"\x00\x12~\n\rHasPermission\x12\x34.pro.omni.oms.api.v1.users.user.HasPermissionRequest\x1a\x35.pro.omni.oms.api.v1.users.user.HasPermissionResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.users.user_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _USER._serialized_start = 137
    _USER._serialized_end = 587
    _GROUP._serialized_start = 590
    _GROUP._serialized_end = 790
    _ACTION._serialized_start = 793
    _ACTION._serialized_end = 1008
    _ACCESS._serialized_start = 1011
    _ACCESS._serialized_end = 1259
    _USERCREATEREQUEST._serialized_start = 1262
    _USERCREATEREQUEST._serialized_end = 1661
    _USERCREATERESPONSE._serialized_start = 1664
    _USERCREATERESPONSE._serialized_end = 1811
    _USERREADREQUEST._serialized_start = 1814
    _USERREADREQUEST._serialized_end = 2179
    _USERREADRESPONSE._serialized_start = 2182
    _USERREADRESPONSE._serialized_end = 2387
    _USERUPDATEREQUEST._serialized_start = 2389
    _USERUPDATEREQUEST._serialized_end = 2516
    _USERUPDATERESPONSE._serialized_start = 2519
    _USERUPDATERESPONSE._serialized_end = 2666
    _USERDELETEREQUEST._serialized_start = 2668
    _USERDELETEREQUEST._serialized_end = 2755
    _USERDELETERESPONSE._serialized_start = 2757
    _USERDELETERESPONSE._serialized_end = 2852
    _USERCHANGEPASSWORDREQUEST._serialized_start = 2855
    _USERCHANGEPASSWORDREQUEST._serialized_end = 2994
    _USERCHANGEPASSWORDRESPONSE._serialized_start = 2996
    _USERCHANGEPASSWORDRESPONSE._serialized_end = 3099
    _USERCHANGEEMAILREQUEST._serialized_start = 3102
    _USERCHANGEEMAILREQUEST._serialized_end = 3232
    _USERCHANGEEMAILRESPONSE._serialized_start = 3234
    _USERCHANGEEMAILRESPONSE._serialized_end = 3334
    _GROUPCREATEREQUEST._serialized_start = 3337
    _GROUPCREATEREQUEST._serialized_end = 3489
    _GROUPCREATERESPONSE._serialized_start = 3492
    _GROUPCREATERESPONSE._serialized_end = 3642
    _GROUPREADREQUEST._serialized_start = 3645
    _GROUPREADREQUEST._serialized_end = 4011
    _GROUPREADRESPONSE._serialized_start = 4014
    _GROUPREADRESPONSE._serialized_end = 4222
    _GROUPUPDATEREQUEST._serialized_start = 4225
    _GROUPUPDATEREQUEST._serialized_end = 4355
    _GROUPUPDATERESPONSE._serialized_start = 4358
    _GROUPUPDATERESPONSE._serialized_end = 4508
    _GROUPDELETEREQUEST._serialized_start = 4510
    _GROUPDELETEREQUEST._serialized_end = 4598
    _GROUPDELETERESPONSE._serialized_start = 4600
    _GROUPDELETERESPONSE._serialized_end = 4696
    _ACTIONCREATEREQUEST._serialized_start = 4699
    _ACTIONCREATEREQUEST._serialized_end = 4862
    _ACTIONCREATERESPONSE._serialized_start = 4865
    _ACTIONCREATERESPONSE._serialized_end = 5018
    _ACTIONREADREQUEST._serialized_start = 5021
    _ACTIONREADREQUEST._serialized_end = 5388
    _ACTIONREADRESPONSE._serialized_start = 5391
    _ACTIONREADRESPONSE._serialized_end = 5602
    _ACTIONUPDATEREQUEST._serialized_start = 5605
    _ACTIONUPDATEREQUEST._serialized_end = 5738
    _ACTIONUPDATERESPONSE._serialized_start = 5741
    _ACTIONUPDATERESPONSE._serialized_end = 5894
    _ACTIONDELETEREQUEST._serialized_start = 5896
    _ACTIONDELETEREQUEST._serialized_end = 5985
    _ACTIONDELETERESPONSE._serialized_start = 5987
    _ACTIONDELETERESPONSE._serialized_end = 6084
    _ACCESSCREATEREQUEST._serialized_start = 6087
    _ACCESSCREATEREQUEST._serialized_end = 6227
    _ACCESSCREATERESPONSE._serialized_start = 6230
    _ACCESSCREATERESPONSE._serialized_end = 6383
    _ACCESSREADREQUEST._serialized_start = 6386
    _ACCESSREADREQUEST._serialized_end = 6753
    _ACCESSREADRESPONSE._serialized_start = 6756
    _ACCESSREADRESPONSE._serialized_end = 6968
    _ACCESSUPDATEREQUEST._serialized_start = 6971
    _ACCESSUPDATEREQUEST._serialized_end = 7104
    _ACCESSUPDATERESPONSE._serialized_start = 7107
    _ACCESSUPDATERESPONSE._serialized_end = 7260
    _ACCESSDELETEREQUEST._serialized_start = 7262
    _ACCESSDELETEREQUEST._serialized_end = 7351
    _ACCESSDELETERESPONSE._serialized_start = 7353
    _ACCESSDELETERESPONSE._serialized_end = 7450
    _HASPERMISSIONREQUEST._serialized_start = 7452
    _HASPERMISSIONREQUEST._serialized_end = 7568
    _HASPERMISSIONRESPONSE._serialized_start = 7571
    _HASPERMISSIONRESPONSE._serialized_end = 7745
    _USERSSERVICE._serialized_start = 7748
    _USERSSERVICE._serialized_end = 10109
# @@protoc_insertion_point(module_scope)
